@@ -38,7 +38,6 @@ import sys
 import os
 import socket
 import time
-import getpass
 import email
 import poplib
 import imaplib
@@ -655,8 +654,9 @@ class POP3RetrieverBase(RetrieverSkeleton):
         self.log.trace()
         # Handle password
         if self.conf.get('password', None) is None:
-            self.conf['password'] = getpass.getpass(
-                'Enter password for %s:  ' % self
+            self.conf['password'] = get_password(
+                self, self.conf['username'], self.conf['server'], 'pop3', 
+                self.log
             )
         RetrieverSkeleton.initialize(self, options)
         try:
@@ -1014,20 +1014,22 @@ class IMAPRetrieverBase(RetrieverSkeleton):
 
     def _getmsgbyid(self, msgid):
         self.log.trace()
-        return self._getmsgpartbyid(msgid, '(RFC822)')
+        return self._getmsgpartbyid(msgid, '(BODY.PEEK[])')
 
     def _getheaderbyid(self, msgid):
         self.log.trace()
-        return self._getmsgpartbyid(msgid, '(RFC822[header])')
+        return self._getmsgpartbyid(msgid, '(BODY.PEEK[header])')
 
     def initialize(self, options):
         self.log.trace()
         # Handle password
         if (self.conf.get('password', None) is None
                 and not (HAVE_KERBEROS_GSS and self.conf['use_kerberos'])):
-            self.conf['password'] = getpass.getpass(
-                'Enter password for %s:  ' % self
+            self.conf['password'] = get_password(
+                self, self.conf['username'], self.conf['server'], 'imap',
+                self.log
             )
+            
         RetrieverSkeleton.initialize(self, options)
         try:
             self.log.trace('trying self._connect()' + os.linesep)
